# -*- coding: utf-8 -*-
from django.conf import settings
from django.utils.translation import ugettext as _
from django.contrib import admin

from jmb.jadmin import JumboModelAdmin, AjaxInline, ConstrainedModelForm, register_inline

from . import models


class DomainAjaxInline(AjaxInline):
    model = models.Domain
    fk_name = ''  
    width = 1000
    list_display = ('status', 'name', 'transport', 
                    'get_edit_icon_iframe', 'get_delete_icon_iframe', )

class AccountAjaxInline(AjaxInline):
    model = models.Account
    fk_name = 'domain'  
    list_display = ('status', 'account', 'transport', 'home_dir', 
                    'get_edit_icon_iframe', 'get_delete_icon_iframe', )

class AliasAjaxInline(AjaxInline):
    model = models.Alias
    fk_name = 'domain'  
    list_display = ('status', 'alias', 'get_edit_icon_iframe', 'get_delete_icon_iframe',  )


class AccountAdmin(JumboModelAdmin): 
    advanced_search_fields = (
        ('status', 'postmaster', 'domain'),
        ('account__icontains', 'home_dir'),
        ('user', 'transport'),
    )
    list_display = ('get_edit_icon_iframe', 'get_delete_icon_iframe', 
                    'status', 'domain', 'account', )
    
class AliasAdmin(JumboModelAdmin): 
    advanced_search_fields = (
        ('status', 'domain'),
        ('alias', 'address__icontains', ) 
    )

    list_display = ('get_edit_icon_iframe', 'get_delete_icon_iframe', 
                    'domain', 'alias', 'address')

class DomainAdmin(JumboModelAdmin): 
    advanced_search_fields = (
        ('name__icontains', 'users', 'transport'),
        ('status', 'postmaster', ),
#        ('accounts__account__icontains') ,
    )
    fieldsets = (
        (_('Main'), {
            'classes': ('collapse',),
            'fields': (
                ('date_create', 'date_last_modify', 'creator', )
                )
        }),
        (_('General'), {
            'fields': (
                ('status', 'name',),
                ('transport', 'postmaster', ),
                ('domain_transport_wins', 'check_relay_users'),
                ('users',),
                ('quota', 'antispam', ),
                ('disable_imap_login', 'disable_pop_login', ),
                )
        }),
        (_('Description'), {
            'classes': ('collapse',),
            'fields': (
                ('description', ),
                )
        }),
        
    )
    list_display = ('get_edit_icon_iframe', 'get_delete_icon_iframe', 
                    'status', 'name', 'transport')
    tabs = (
         ('main', {}),
         ('accounts', {'items': [AccountAjaxInline]}),
         ('aliases', {'items': [AliasAjaxInline]}),
    )

admin.site.register(models.Domain, DomainAdmin)
admin.site.register(models.Account, AccountAdmin)
admin.site.register(models.Alias, AliasAdmin)

register_inline(AccountAjaxInline)
register_inline(AliasAjaxInline)
register_inline(DomainAjaxInline)
