# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Account',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(auto_now_add=True, verbose_name=b'Data Creazione')),
                ('date_last_modify', models.DateTimeField(auto_now=True, verbose_name=b'Data Modifica')),
                ('status', models.IntegerField(default=b'1', verbose_name=b'Stato', choices=[(1, b'Active'), (0, b'Inactive')])),
                ('account', models.CharField(max_length=127, verbose_name=b'Account')),
                ('pwd', models.CharField(max_length=127, verbose_name=b'Password')),
                ('quota', models.IntegerField(help_text=b'In Megabytes (MB)', verbose_name=b'Quota')),
                ('home_dir', models.CharField(max_length=255, null=True, verbose_name=b'Path', blank=True)),
                ('backup', models.BooleanField(default=False, verbose_name=b'Backup')),
                ('antispam', models.BooleanField(default=False, verbose_name=b'Antispam')),
                ('disable_imap_login', models.BooleanField(default=True, verbose_name=b'Disable IMAP')),
                ('disable_pop_login', models.BooleanField(default=True, verbose_name=b'Disable POP')),
                ('transport', models.CharField(help_text='If an IP is present all email for this domain will be forwarded to this IP', max_length=50, null=True, blank=True)),
            ],
            options={
                'verbose_name': 'Account Mail',
                'verbose_name_plural': 'Account Mail',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Alias',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(auto_now_add=True, verbose_name=b'Data Creazione')),
                ('date_last_modify', models.DateTimeField(auto_now=True, verbose_name=b'Data Modifica')),
                ('status', models.IntegerField(default=b'1', verbose_name=b'Stato', choices=[(1, b'Active'), (0, b'Inactive')])),
                ('alias', models.CharField(help_text=b"Simple name without '@' simbol", max_length=127)),
                ('address', models.CharField(help_text=b'A list of names or addresses. Simple names are searched for in this domain', max_length=127, verbose_name=b'Email')),
            ],
            options={
                'verbose_name': 'Alias',
                'verbose_name_plural': 'Aliases',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Domain',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(auto_now_add=True, verbose_name=b'Data Creazione')),
                ('date_last_modify', models.DateTimeField(auto_now=True, verbose_name=b'Data Modifica')),
                ('status', models.IntegerField(default=b'1', verbose_name=b'Stato', choices=[(1, b'Active'), (0, b'Inactive')])),
                ('name', models.CharField(unique=True, max_length=127, verbose_name='Domain')),
                ('description', models.TextField(verbose_name='Descrizione', blank=True)),
                ('users', models.SmallIntegerField(null=True, verbose_name='Max Utenti', blank=True)),
                ('quota', models.IntegerField(help_text=b'In Megabytes (MB)', null=True, verbose_name=b'Max Quota', blank=True)),
                ('antispam', models.BooleanField(default=False, verbose_name=b'Antispam')),
                ('disable_imap_login', models.BooleanField(default=True, verbose_name='Disable IMAP')),
                ('disable_pop_login', models.BooleanField(default=True, verbose_name='Disable POP')),
                ('transport', models.CharField(help_text='If an IP is present all email for this domain will be forwarded to this IP', max_length=255, verbose_name=b'Transport', blank=True)),
                ('domain_transport_wins', models.BooleanField(default=True)),
                ('check_relay_users', models.BooleanField(default=True, help_text="If relay is enable (transport != virtual), check user's existance")),
                ('creator', models.ForeignKey(related_name='creator', verbose_name='Created by', to=settings.AUTH_USER_MODEL)),
                ('postmaster', models.ManyToManyField(to=settings.AUTH_USER_MODEL, verbose_name=b'Postmaster', blank=True)),
            ],
            options={
                'verbose_name': 'Dominio Mail',
                'verbose_name_plural': 'Domini Mail',
                'permissions': (('supermaster_perm', 'complete mailserver administration'), ('postmaster_perm', 'mailserver administration related to his domains')),
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Vacation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(auto_now_add=True, verbose_name=b'Data Creazione')),
                ('date_last_modify', models.DateTimeField(auto_now=True, verbose_name=b'Data Modifica')),
                ('status', models.IntegerField(default=b'1', verbose_name=b'Stato', choices=[(1, b'Active'), (0, b'Inactive')])),
                ('date_start', models.DateField(verbose_name=b'Data Inizio')),
                ('date_end', models.DateField(verbose_name=b'Data Fine')),
                ('vacation', models.TextField(verbose_name=b'Vacation', blank=True)),
                ('account', models.ForeignKey(verbose_name=b'Account', to='mailserver.Account')),
            ],
            options={
                'verbose_name': 'Vacation',
                'verbose_name_plural': 'Vacation',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='alias',
            name='domain',
            field=models.ForeignKey(related_name='aliases', verbose_name=b'dominio', to='mailserver.Domain'),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='alias',
            unique_together=set([('alias', 'address', 'domain')]),
        ),
        migrations.AddField(
            model_name='account',
            name='domain',
            field=models.ForeignKey(related_name='accounts', verbose_name=b'dominio', to='mailserver.Domain'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='account',
            name='postmaster',
            field=models.ForeignKey(related_name='postmaster', verbose_name=b'Creato da', to=settings.AUTH_USER_MODEL),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='account',
            name='user',
            field=models.ForeignKey(verbose_name=b'User', blank=True, to=settings.AUTH_USER_MODEL, null=True),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='account',
            unique_together=set([('account', 'domain')]),
        ),
    ]
